# AMSHAN

Package to help decode smart power meter data stream
of Cosem HDLC frames.

The package supports formats of Aidon, Kaifa and Kamstrum
meters used in Norway (see https://www.nek.no/info-ams-han-utviklere/).
